@@ -403,17 +403,7 @@ void TargetList::surfaceMisfit(double& totalMisfit, double& totalWeight,
     totalMisfit+=_autocorrTarget.misfitWeight()*individualMisfit;
     totalWeight+=_autocorrTarget.misfitWeight();
   }
-
-  if(_ellipticityCurveTarget.selected() && !_ellipticityCurveTarget.curves().isEmpty()) {
-    individualMisfit=curveMisfit(_ellipticityCurveTarget.curves(), *_ellipticityFactory, _ellipticityCurveTarget, nDimensions);
-    if(individualMisfit<0.0) {
-      ok=false;
-      return;
-    }
-    totalMisfit+=_ellipticityCurveTarget.misfitWeight()*individualMisfit;
-    totalWeight+=_ellipticityCurveTarget.misfitWeight();
-  }
-
+  // Before ell curve target because angular degree ellipticity is not accepted by peak refinements
   if(_ellipticityPeakTarget.selected() && _ellipticityPeakTarget.value().isValid()) {
     // TODO includes misfitType
     // Ellipticity peak misfit is not a L2 norm but just a L1...
@@ -424,6 +414,25 @@ void TargetList::surfaceMisfit(double& totalMisfit, double& totalWeight,
     totalMisfit+=_ellipticityPeakTarget.misfitWeight()*individualMisfit;
     totalWeight+=_ellipticityPeakTarget.misfitWeight();
   }
+  if(_ellipticityFactory) { // Switch to angular degree ellipticity even if no misfit on the curve
+                            // Required for consistent ploting
+    // Work around for 3.3.6 without modifying EllipticityFactory API
+    // On 3.4 branch, implemented in EllipticityFactory::atanDeg()
+    _ellipticityFactory->signedValues()->atanDeg();
+    if(_ellipticityFactory->absoluteValues()) {
+      *_ellipticityFactory->absoluteValues()=*_ellipticityFactory->signedValues();
+      _ellipticityFactory->absoluteValues()->abs();
+    }
+  }
+  if(_ellipticityCurveTarget.selected() && !_ellipticityCurveTarget.curves().isEmpty()) {
+    individualMisfit=curveMisfit(_ellipticityCurveTarget.curves(), *_ellipticityFactory, _ellipticityCurveTarget, nDimensions);
+    if(individualMisfit<0.0) {
+      ok=false;
+      return;
+    }
+    totalMisfit+=_ellipticityCurveTarget.misfitWeight()*individualMisfit;
+    totalWeight+=_ellipticityCurveTarget.misfitWeight();
+  }
 }
 
 void TargetList::refractionMisfit(double& totalMisfit, double& totalWeight,
