@@ -82,6 +82,24 @@ namespace GeopsyCore {
   void SignalProcess::saveStep(const QString& tag)
   {
     TRACE;
+    // Save history to signal comments
+    if(_steps.isEmpty()) {
+      for(SubSignalPool::iterator it=_current->begin(); it!=_current->end(); it++) {
+        Signal * sig=*it;
+        Comments& c=sig->beginModifyMetaData<Comments>();
+        if(sig->file()) {
+          c+="'"+sig->file()->name()+"' at index "+QString::number(sig->numberInFile())+"\n";
+        }
+        sig->endModifyMetaData(c);
+      }
+    } else {
+      for(SubSignalPool::iterator it=_current->begin(); it!=_current->end(); it++) {
+        Signal * sig=*it;
+        Comments& c=sig->beginModifyMetaData<Comments>();
+        c+="  "+tag+"\n";
+        sig->endModifyMetaData(c);
+      }
+    }
     _steps.append(*_current);
     _steps.last().setName(tag);
   }
@@ -113,13 +131,6 @@ namespace GeopsyCore {
   void SignalProcess::addToHistory(const QString& s)
   {
     _history+=s;
-    // Save history to comments
-    for(SubSignalPool::iterator it=_current->begin(); it!=_current->end(); it++) {
-      Signal * sig=*it;
-      Comments& c=sig->beginModifyMetaData<Comments>();
-      c+=s;
-      sig->endModifyMetaData(c);
-    }
   }
 
   void SignalProcess::fastFourierTransform(DoubleSignal::SignalType st)
