@@ -147,12 +147,8 @@ namespace QGpCoreMath {
     if(std::isfinite(s.minimum()) &&
        std::isfinite(s.maximum()) &&
        s.minimum()<s.maximum()) {
-      Curve<Point1D> c;
-      c.line(s.minimum(), s.maximum());
-      c.resample(ny(), s.minimum(), s.maximum(), _ySampling);
-      QVector<double> values=c.xVector();
       for(int i=0; i<ny(); i++) {
-        setY(i, values[i]);
+        setY(i, s.value(i));
       }
       return true;
     } else {
